@@ -184,10 +184,16 @@ static char
 		  filename = find_info_part (items[0], file);
 		  str = open_info_file (filename);
 		  if (!str) {
-		  	return NULL;
+			g_strfreev (items);
+		  	continue;
 		  }
 			pages = g_strsplit (str, "", 2);
 			g_free (str);
+			if (!pages[1]) {
+				g_strfreev (items);
+				g_strfreev (pages);
+		  		continue;
+			}
 
 			offset =  atoi(items[1]);
 			plength = strlen(pages[1]);
@@ -354,6 +360,12 @@ GtkTreeIter * find_real_sibling (GtkTreeModel *model,
       title = gtk_tree_model_get_string_from_iter (model, r);
   }
 
+  if (!g_str_equal (title, reftitle))
+    {
+      gtk_tree_iter_free (tmp);
+      tmp = NULL;
+    }
+
   gtk_tree_iter_free (r);
   g_free (title);
   g_free (reftitle);
@@ -486,11 +498,14 @@ process_page (GtkTreeStore *tree, GHashTable *nodes2offsets,
 	}
 
 	d (if (iter) debug_print (DB_DEBUG, "Have a valid iter, storing for %s\n", node));
+
 	g_hash_table_insert (nodes2iters, g_strdup (node), iter);
 	debug_print (DB_DEBUG, "size: %i\n", g_hash_table_size (nodes2iters));
 
-	tmp = g_strdup_printf ("%i",
-			       node2page (nodes2offsets, offsets2pages, node));
+	/*tmp = g_strdup_printf ("%i",
+	  node2page (nodes2offsets, offsets2pages, node));*/
+	tmp = g_strdup (node);
+	tmp = g_strdelimit (tmp, " ", '_');
 	gtk_tree_store_set (tree, iter,
 			    COLUMN_PAGE_NO, tmp,
 			    COLUMN_PAGE_NAME, node,
@@ -785,7 +800,9 @@ resolve_frag_id (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 		      -1);
   if (g_str_equal (page_name, *xref)) {
     g_free (*xref);
-    *xref = g_strdup (page_no);
+    *xref = g_strdup (page_name);
+    *xref = g_strdelimit (*xref, " ", '_');
+
     g_free (page_name);
     g_free (page_no);
     return TRUE;
