@@ -31,8 +31,7 @@
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 #include <string.h>
-#include <rarian-info.h>
-#include <rarian-man.h>
+#define I_KNOW_RARIAN_0_8_IS_UNSTABLE
 #include <rarian.h>
 
 #include "yelp-utils.h"
@@ -73,7 +72,9 @@ resolve_process_ghelp (char *uri, gchar **result)
 	else 
 	    mime = gnome_vfs_get_mime_type (*result);
 	
-	if (g_str_equal (mime, "text/xml") || 
+	if (!mime) {
+	    type = YELP_RRN_TYPE_ERROR;
+	} else if (g_str_equal (mime, "text/xml") || 
 	    g_str_equal (mime, "application/docbook+xml") || 
 	    g_str_equal (mime, "application/xml"))
 	    type = YELP_RRN_TYPE_DOC;
@@ -385,7 +386,10 @@ yelp_uri_resolve (gchar *uri, gchar **result, gchar **section)
     } else if (!strncmp (uri, "x-yelp-toc:", 11)) {
 	ret = YELP_RRN_TYPE_TOC;
 	if (strlen (uri) > 11) {
-	    *section = g_strdup (&uri[11]);
+	    gint frag = 11;
+	    while (uri[frag] == '#' || uri[frag] == '?')
+		frag++;
+	    *section = g_strdup (&uri[frag]);
 	} else {
 	    *section = g_strdup("index");
 	}
