@@ -1584,9 +1584,9 @@ window_do_load_html (YelpWindow    *window,
 	goto done;
     }
 
-    base_uri = g_filename_to_uri (real_uri, NULL, NULL);
+    base_uri = g_filename_to_uri (uri, NULL, NULL);
     if (frag_id) {
-	real_uri = g_strconcat (base_uri, "#", frag_id);
+	real_uri = g_strconcat (base_uri, "#", frag_id, NULL);
 	g_free (base_uri);
     } else {
 	real_uri = base_uri;
@@ -2159,7 +2159,7 @@ window_reload_cb (GtkAction *action, YelpWindow *window)
 	if (window->priv->current_request > -1) {
 	    yelp_document_cancel_page (window->priv->current_document, window->priv->current_request);
 	}
-	//g_object_unref (window->priv->current_document);
+	/*g_object_unref (window->priv->current_document);*/
 	window->priv->current_document = NULL;
 	yelp_window_load (window, window->priv->req_uri);
     }
