@@ -25,6 +25,7 @@
 
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 #include "yelp-base.h"
 #include "yelp-utils.h"
@@ -61,7 +62,7 @@ GtkWidget *      yelp_window_new             (GNode         *doc_tree,
 					      GList         *index);
 void             yelp_window_load            (YelpWindow    *window,
 					      const gchar   *uri);
-YelpDocInfo *    yelp_window_get_doc_info    (YelpWindow    *window);
+const gchar *    yelp_window_get_uri         (YelpWindow    *window);
 GtkUIManager *   yelp_window_get_ui_manager  (YelpWindow    *window);
 
 #endif /* __YELP_WINDOW_H__ */
